autoHide property
Determines whether the scrollbar should automatically hide after a period of inactivity.
Defaults to true.
Implementation
final bool autoHide;
Determines whether the scrollbar should automatically hide after a period of inactivity.
Defaults to true.
final bool autoHide;