opacityAnimationDuration property

Duration opacityAnimationDuration
final

The duration of the animation for showing and hiding the scrollbar.

This Duration is used for the opacity animation triggered by autoHide.

Defaults to 250 milliseconds.

Implementation

final Duration opacityAnimationDuration;