padding property
The padding around the scrollbar track.
This value defines the space between the scrollbar and the edges of the screen.
Defaults to 8 logical pixels.
Implementation
final double padding;
The padding around the scrollbar track.
This value defines the space between the scrollbar and the edges of the screen.
Defaults to 8 logical pixels.
final double padding;