thumbColor property

Color? thumbColor
final

Overrides the default color of the scrollbar thumb.

If not specified, the thumb color is derived from the scrollbarTheme.thumbColor in the application's theme. If that is also null, it falls back to the theme's highlightColor with an alpha of 255.

Implementation

final Color? thumbColor;