trackColor property

Color? trackColor
final

Overrides the default color of the scrollbar track.

If not specified, the track color is derived from the scrollbarTheme.trackColor in the application's theme. If that is also null, it falls back to the theme's highlightColor.

Implementation

final Color? trackColor;